.. _mutable_toplevel:

Mutation Tracking
==================

.. automodule:: sqlalchemy.ext.mutable

API Reference
-------------

.. autoclass:: MutableBase
    :members: _parents, coerce

.. autoclass:: Mutable
    :members:
    :inherited-members:
    :private-members:

.. autoclass:: MutableComposite
    :members:

.. autoclass:: MutableDict
	:members:
	:undoc-members:

.. autoclass:: MutableList
	:members:
	:undoc-members:

.. autoclass:: MutableSet
	:members:
	:undoc-members:


